@@ -1,5 +1,5 @@
 __all__ = ('UserProfilePoint', 'UserProfileObjectPoint', 'RussianProfilePoint', 'RussianProfileObjectPoint',
-           'ProfileObjectPoint', 'UserProfileIpExistsPoint', 'SetCreditScorePoint',
+           'ProfileObjectPoint', 'UserProfileIpExistsPoint', 'SetCreditScorePoint', 'DocumentPoint',
            )
 
 from expressmoney.api import *
@@ -79,7 +79,6 @@ class RussianProfileUpdateContract(ProfileUpdateContract):
     passport_number = serializers.CharField(max_length=6)
     passport_code = serializers.CharField(max_length=16)
     passport_date = serializers.DateField()
-    document = serializers.CharField(max_length=512, allow_null=True, allow_blank=True)
 
 
 class RussianProfileCreateContract(ProfileCreateContract):
@@ -90,7 +89,6 @@ class RussianProfileCreateContract(ProfileCreateContract):
     passport_date = serializers.DateField()
     income = serializers.IntegerField(allow_null=True, required=False)
     snils = serializers.CharField(max_length=64, allow_null=True, allow_blank=True)
-    document = serializers.CharField(max_length=512, allow_null=True, allow_blank=True)
 
 
 class RussianProfileReadContract(ProfileReadContract, ):
@@ -106,6 +104,14 @@ class RussianProfileReadContract(ProfileReadContract, ):
     snils = serializers.CharField(max_length=64, allow_null=True, allow_blank=True)
 
 
+class DocumentCreateContract(Contract):
+    document = serializers.CharField(max_length=128)
+
+
+class DocumentReadContract(Contract):
+    document = serializers.CharField(max_length=128)
+
+
 class UserProfileIpExistsCreateContract(Contract):
     ip = serializers.IPAddressField()
 
@@ -160,6 +166,12 @@ class LogID(ID):
     _view_set = 'log'
 
 
+class DocumentID(ID):
+    _service = SERVICE
+    _app = 'profiles'
+    _view_set = 'document'
+
+
 class UserProfilePoint(CreatePointMixin, ContractPoint):
     _point_id = UserProfileID()
     _create_contract = UserProfileCreateContract
@@ -200,3 +212,10 @@ class SetCreditScorePoint(CreatePointMixin, ContractPoint):
 class LogPoint(CreatePointMixin, ContractPoint):
     _point_id = LogID()
     _create_contract = LogCreateContract
+
+
+class DocumentPoint(ListPointMixin, CreatePointMixin, ContractPoint):
+    _point_id = DocumentID()
+    _create_contract = DocumentCreateContract
+    _read_contract = DocumentReadContract
+    _sort_by = 'created'
